#!/usr/bin/env perl

# Pragmas.
use strict;
use warnings;

# Modules.
use Encode qw(encode_utf8);
use Mock::Person::SK;

# Get all last male names.
my @last_males = @Mock::Person::SK::last_male;

# Print out.
print sort map { encode_utf8($_)."\n" } @last_males;

# Output:
# Acsai
# Adamec
# Aina
# Alt
# Altnau
# Amri
# Andreánsky
# Andrich
# Anjel
# Antl
# Argesheimer
# Auxt
# Babarík
# Babnič
# Bacúšan
# Baliak
# Balkovič
# Ballinger
# Baláž
# Bandura
# Banský
# Barbírik
# Barek
# Barháč
# Barinek
# Bartánus
# Belko
# Belkovič
# Belopotocký
# Bendík
# Benč
# Beraxa
# Beránek
# Berčík
# Bese
# Betka
# Beňo
# Beňuš
# Bešenda
# Bihári
# Blaho
# Blišťan
# Bogus
# Boháčik
# Borovička
# Boroš
# Bowman
# Bošeľa
# Brady
# Brenkus
# Brečka
# Brief
# Brozman
# Brož
# Brtán
# Brucháč
# Bruoth
# Bubelíny
# Budaj
# Bukovský
# Bulla
# Buncsek
# Bunčiak
# Burdy
# Bursa
# Butora
# Buvala
# Bánik
# Bártek
# Bútora
# Caban
# Cambel
# Cesnak
# Chabada
# Chamar
# Chovan
# Chovanec
# Christ
# Chudík
# Cibulka
# Cibuľa
# Cipciar
# Citterberg
# Combrink
# Corrado
# Couturier
# Csáky
# Cvanga
# Datko
# Daxner
# Degúl
# Demian
# Demko
# Demuth
# Deppert
# Dettweiler
# Divok
# Dobrota
# Dobrík
# Dolinský
# Dolňan
# Doncsiák
# Donoval
# Doppler
# Dorica
# Dostál
# Dovala
# Dočekal
# Drga
# Dráb
# Dubenský
# Dubéci
# Dubíny
# Dudáš
# Dugát
# Duhan
# Dunajský
# Dupej
# Durek
# Déneši
# Džuka
# Eckel
# Engler
# Evanoff
# Eyrich
# Fabrícius
# Farmer
# Farárik
# Faschko
# Fasco
# Fasko
# Faskó
# Fassco
# Faška
# Faško
# Fedor
# Fehér
# Ferenc
# Ferenčík
# Ferianc
# Ferrara
# Ferster
# Figľuš
# Fillo
# Filo
# Fitkomides
# Formánek
# Fortiak
# Francik
# Franko
# Franzgreb
# Frgelec
# Frntol
# Futas
# Gajdoš
# Gajdošík
# Gazdík
# Gašparovič
# Gašperan
# Gažura
# Gažúrik
# Giablo
# Giertl
# Giertli
# Gilla
# Glasmacher
# Gloner
# Golian
# Gonda
# Grakalskis
# Gramla
# Green
# Grlický
# Gronel
# Gronell
# Gáfrik
# Gömöry
# Haas
# Habovčík
# Hais
# Hajdusik
# Hajdúk
# Halaj
# Hamaj
# Hambálek
# Handlír
# Haraburda
# Harmata
# Harter
# Harvanka
# Hauck
# Haviar
# Havlíček
# Havran
# Havrila
# Hawes
# Heckmann
# Helena
# Herman
# Hoechstetter
# Hojčuš
# Hoover
# Horský
# Horvát
# Horváth
# Hosek
# Howard
# Hoška
# Hoško
# Hrbek
# Hrbáň
# Hrmelár
# Hrnčiarik
# Hruška
# Hrynda
# Hrňo
# Hudec
# Hurdálek
# Hutka
# Hutta
# Huťka
# Húsenica
# Húska
# Ionadi
# Ivan
# Ivanec
# Ivaniš
# Ištván
# Jankovič
# Janošková
# Jančik
# Jančo
# Javorčík
# Javorčík
# Jerguš
# Johan
# Jokl
# Juhász
# Juracek
# Jágerčík
# Jánošík
# Jávorský
# Kabar
# Kachnič
# Kaclik
# Kaclík
# Kadecký
# Kahoun
# Kalaský
# Kamenský
# Kantoris
# Kantárik
# Kapitán
# Kappler
# Kapusta
# Kardoš
# Karásek
# Kaslik
# Kelvány
# Kieborz
# Kieffer
# Kizek
# Klafczynski
# Klajban
# Klein
# Kleskeň
# Klimek
# Kliment
# Klimo
# Kloboučník
# Klíma
# Kmetz
# Knapčok
# Knoško
# Kochan
# Kocprd
# Kodric
# Koenig
# Kohút
# Kolaj
# Kolega
# Kolesár
# Komora
# Komora
# Koprda
# Korbeľ
# Kordulič
# Korenačka
# Korim
# Kostka
# Kotkuliak
# Kotrík
# Kotrčka
# Kotyra
# Kovalik
# Kovalík
# Koválik
# Kováč
# Kováčik
# Kozar
# Kozelnicky
# Kozma
# Kozák
# Kočiš
# Koľaj
# Košius
# Košičiar
# Koštial
# Košík
# Kožiak
# Kožiar
# Krajčovič
# Kralik
# Krammer
# Kraner
# Krejčí
# Krenický
# Kresák
# Krieger
# Krištek
# Krištof
# Krištál
# Krkoška
# Krnáč
# Krupa
# Kruszynski
# Krušinský
# Kružliak
# Krystosik
# Krídlo
# Kršák
# Kubacký
# Kubaský
# Kubica
# Kubisch
# Kubizniak
# Kubička
# Kubiš
# Kubos
# Kubus
# Kudor
# Kuhnsman
# Kuna
# Kuntzler
# Kupec
# Kupčok
# Kurajda
# Kuricz
# Kučera
# Kán
# Kösegi
# Kúdelka
# Küntzler
# Kľavko
# Kňaze
# Kňazík
# Laitman
# Langhoerig
# Lanz
# Laubert
# Laule
# Laurinc
# Ledbetter
# Ledňa
# Lefkowitz
# Lehocký
# Lehotský
# Leitman
# Leitner
# Lenarth
# Lepko
# Letko
# Lešták
# Libič
# Lichvár
# Licko
# Lie
# Lihan
# Lipták
# Liskay
# Lisý
# Litva
# Ličko
# Lojko
# Lojkovič
# Lopušný
# Lovecký
# Luce
# Ludvik
# Lukáč
# Lupták
# Láni
# Macko
# Macula
# Macuľa
# Macz
# Madda
# Madro
# Magic
# Majerčík
# Makovíni
# Malatinec
# Malga
# Malloy
# Malus
# Mangold
# Marciň
# Marconi
# Marek
# Marianek
# Marinko
# Martinec
# Martzek
# Maruška
# Maruškin
# Marzec
# Matejovič
# Matinec
# Matoš
# Matta
# Matušák
# Mauritz
# Mayhew
# Mazanec
# Maľo
# Mede
# Medveď
# Mereš
# Meyer
# Michalčík
# Michelčík
# Mihala
# Mihál
# Mikloško
# Mikovíny
# Mikuláši
# Mikulík
# Mikuš
# Mindek
# Mindžák
# Mitický
# Mitterbach
# Mitterka
# Miťko
# Mlynarčík
# Mojčák
# Mokoš
# Molota
# Molčan
# Moorcroft
# Moravčík
# Morgenstern
# Morhard
# Motyka
# Muller
# Multán
# Murphy
# Murín
# Mutňan
# Márton
# Máček
# Mühl
# Müller
# Nagel
# Neal
# Nelson
# Nemčok
# Nezbeda
# Nichols
# Nikel
# Nikolaides
# Nociar
# Noellner
# Noga
# Novak
# Novysedlák
# Nováček
# Nuota
# Náhlovský
# Németh
# Oberhauser
# Obrtanec
# Oceľ
# Odelga
# Okruhlica
# Olsby
# Olšiak
# Omasta
# Ondruška
# Ondrášik
# Oravec
# Oravský
# Paff
# Pajtinka
# Palazzo
# Paleš
# Palič
# Pampúrik
# Panigaj
# Pančík
# Patúš
# Paulen
# Paulenka
# Pauliak
# Paulovič
# Pavelka
# Pavlečka
# Pavlove
# Pavlík
# Pavčiak
# Pazár
# Pačesa
# Pekár
# Peniak
# Pepich
# Petljanska
# Petrin
# Petruš
# Petráš
# Pečienka
# Peško
# Pfender
# Piatek
# Pierce
# Pikula
# Piliar
# Piliarkin
# Pilát
# Pindiak
# Pipíš
# Plieštik
# Pltník
# Pobožný
# Podhoľský
# Pohančanik
# Pohančaník
# Pohorelec
# Pohorelský
# Poliak
# Polák
# Polóny
# Ponist
# Posúch
# Potančok
# Poš
# Pravotiak
# Predajňa
# Prečuch
# Profant
# Puci
# Pápai
# Pápaj
# Pôbiš
# Pős
# Radušovský
# Rak
# Rakita
# Rastocky
# Ratay
# Raztocky
# Račák
# Raška
# Remenár
# Remper
# Repka
# Repčiak
# Rezníček
# Ribos
# Ridzoň
# Riedinger
# Rigaud
# Robinson
# Romankiewicz
# Rossi
# Rozkoš
# Rozložný
# Roštár
# Rudáš
# Rusnák
# Ráztocký
# Révay
# Sabo
# Sahó
# Saksa
# Sanitra
# Schaaf
# Schimpf
# Schlebach
# Schmer
# Schneider
# Schnierer
# Schreiner
# Schvarcbacher
# Seiler
# Sekerák
# Senko
# Sepeši
# Sečkáš
# Shiller
# Sieden
# Sihelský
# Siládi
# Siman
# Sirota
# Sitarčík
# Sittler
# Skubák
# Slafkovský
# Slamený
# Sleziak
# Složil
# Slučiak
# Smiešna
# Smiešny
# Soják
# Soucz
# Souček
# Sperka
# Spišjak
# Spodniak
# Springer
# Srnka
# Stadler
# Stanček
# Stančík
# Stehlo
# Steigauf
# Stenczel
# Straka
# Strakota
# Strass
# Striežovský
# Stringer
# Strnad
# Supala
# Surový
# Sutter
# Séleš
# Sýkora
# Takáč
# Tapajčík
# Taxner
# Tačár
# Testevič
# Tetliak
# Tešlár
# Tilka
# Tišliar
# Tkáčik
# Tokár
# Tomajka
# Tonheiser
# Tončík
# Toriška
# Trnavský
# Trubiroh
# Turošík
# Turčan
# Turňa
# Táborský
# Tóth
# Uher
# Ustak
# Vajcík
# Valentino
# Valentko
# Vandlík
# Vaník
# Varga
# Vaslík
# Vašina
# Veládi
# Venger
# Vernársky
# Vetrák
# Veverka
# Vilímek
# Vist
# Vitello
# Vičan
# Vlaszati
# Vlčko
# Vodál
# Vološín
# Vološčuk
# Votroubek
# Vrbovský
# Vrunay
# Wagner
# Wahley
# Weisenpacher
# Wenger
# Witcherley
# Zachar
# Zahorec
# Zajac
# Zajak
# Zambory
# Zaňák
# Zemančík
# Zemko
# Zemánek
# Zettlemoyer
# Zeyst
# Zibrín
# Zingor
# Zlevský
# Zlúky
# Zubal
# Zubák
# Zvara
# Záhorec
# Záturecký
# Čech
# Čelár
# Černák
# Červený
# Čipka
# Čičmanec
# Čižmár
# Čmelík
# Čunderlík
# Ďordík
# Ďuriš
# Ďurčo
# Ďurčík
# Ľuptovčiak
# Ľupták
# Šajgal
# Šajgalík
# Šebo
# Šeco
# Ševčík
# Šimkovič
# Šimon
# Šimuny
# Šimúny
# Šindler
# Šiška
# Škadra
# Škantár
# Škoda
# Škrovina
# Škula
# Škôlka
# Šmajták
# Šmejkal
# Šmidt
# Šmihula
# Šperka
# Šramko
# Štefanko
# Števlík
# Štrba
# Štubniak
# Štubňa
# Štulrajter
# Štulreiter
# Štádler
# Šulej
# Šuran
# Švantner
# Švarcbacher
# Švelka
# Švidraň
# Švihra
# Šťavina
# Žemlička
# Žiak
# Žila
# Žilík
# Žďársky